@@ -22,6 +22,10 @@
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  */
 
+#ifdef HAVE_CONFIG_H
+#  include <config.h>
+#endif
+
 #include <stdlib.h>
 #include <string.h>
 #include <sys/stat.h>
@@ -119,14 +123,11 @@ static void cxp_profile_dispose (GObject * obj)
 	}
 
 	self->priv->dispose_has_run = TRUE;
-	filename = g_build_filename (
-			g_get_home_dir (),
-			".cxp", 
-			self->priv->appname,
-			self->priv->section,
-			NULL );
-	if ((channel =
-	     g_io_channel_new_file (filename, "w", NULL)) != NULL)
+	filename = g_build_filename (g_get_home_dir (),
+				     ".cxp",
+				     self->priv->appname,
+				     self->priv->section, NULL);
+	if ((channel = g_io_channel_new_file (filename, "w", NULL)) != NULL)
 	{
 		g_hash_table_foreach (self->priv->config, cxp_profile_save_file,
 				      channel);
@@ -147,7 +148,7 @@ static void cxp_profile_finalize (GObject * obj)
 	g_free (self->priv);
 }
 
-CxpProfile *cxp_profile_new (const gchar * appname, const gchar *section)
+CxpProfile *cxp_profile_new (const gchar * appname, const gchar * section)
 {
 	CxpProfile *profile;
 	gchar *cxpdir;
@@ -156,10 +157,7 @@ CxpProfile *cxp_profile_new (const gchar * appname, const gchar *section)
 	profile = CXP_PROFILE (g_object_new (CXP_TYPE_PROFILE, NULL));
 	profile->priv->appname = g_strdup (appname);
 	profile->priv->section = g_strdup (section);
-	cxpdir = g_build_filename (
-			g_get_home_dir (),
-			".cxp",
-			NULL);
+	cxpdir = g_build_filename (g_get_home_dir (), ".cxp", NULL);
 	if (!g_file_test (cxpdir, G_FILE_TEST_EXISTS))
 	{
 		if (mkdir (cxpdir, S_IFDIR | 0777) != 0)
@@ -167,10 +165,7 @@ CxpProfile *cxp_profile_new (const gchar * appname, const gchar *section)
 			g_error ("%s couldn't be created.\n", cxpdir);
 		}
 	}
-	appdir = g_build_filename (
-			cxpdir,
-			appname,
-			NULL);
+	appdir = g_build_filename (cxpdir, appname, NULL);
 	if (!g_file_test (appdir, G_FILE_TEST_EXISTS))
 	{
 		if (mkdir (appdir, S_IFDIR | 0777) != 0)
@@ -239,16 +234,17 @@ static void cxp_profile_load_file (CxpProfile * profile)
 	gchar *value;
 	GIOChannel *channel;
 
-	filename = g_build_filename (
-			g_get_home_dir (),
-			".cxp", 
-			profile->priv->appname,
-			profile->priv->section,
-			NULL );
+	filename = g_build_filename (g_get_home_dir (),
+				     ".cxp",
+				     profile->priv->appname,
+				     profile->priv->section, NULL);
 	if ((channel = g_io_channel_new_file (filename, "r", NULL)) == NULL)
 	{
-		g_free(filename);
-		filename = g_build_filename (CONFDIR, profile->priv->appname, profile->priv->section, NULL);
+		g_free (filename);
+		filename =
+			g_build_filename (PACKAGE_CONF_DIR,
+					  profile->priv->appname,
+					  profile->priv->section, NULL);
 		channel = g_io_channel_new_file (filename, "r", NULL);
 	}
 
@@ -263,11 +259,11 @@ static void cxp_profile_load_file (CxpProfile * profile)
 				array = g_strsplit (line, "=", 2);
 				name = g_strdup (array[0]);
 				value = g_strdup (array[1]);
-				g_hash_table_replace(config, name, value);
+				g_hash_table_replace (config, name, value);
 			}
 			g_free (line);
 		}
-		g_io_channel_unref(channel);
+		g_io_channel_unref (channel);
 	}
 	g_free (filename);
 }
